@@ -32,7 +32,7 @@ except ImportError:
 # update it when the contents of directories change.
 if os.path.exists('MANIFEST'): os.remove('MANIFEST')
 
-
+from pkg_resources import parse_version
 from setuptools import Command
 from setuptools.command.build_py import build_py
 from setuptools.config import StaticModule
@@ -56,7 +56,7 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.8.3'
+__version__ = '0.9.0'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
@@ -76,7 +76,7 @@ else:
 # Core Functions
 # ---------------------------------------------------------------------------
 
-def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dist=None):
+def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dist=None, ensured_targets=None):
     """Make a setuptools cmdclass that calls a prebuild function before installing.
 
     Parameters
@@ -89,6 +89,8 @@ def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dis
         The function to call after the develop command.
     post_dist: function
         The function to call after the sdist and wheel commands.
+    ensured_targets: list
+        A list of local file paths that should exist when the dist commands are run
 
     Notes
     -----
@@ -114,11 +116,14 @@ def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dis
         if locals()[name]:
             _make_command(name, locals()[name])
 
+    cmdclass['ensure_targets'] = ensure_targets(ensured_targets or [])
+
     def _make_wrapper(klass, pre_build, post_build):
         class _Wrapped(klass):
             def run(self):
                 if pre_build:
                     self.run_command(pre_build.__name__)
+                self.run_command('ensure_targets')
                 klass.run(self)
                 if post_build:
                     self.run_command(post_build.__name__)
@@ -127,7 +132,7 @@ def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dis
     if pre_develop or post_develop:
         _make_wrapper(develop, pre_develop, post_develop)
 
-    if pre_dist or post_dist:
+    if pre_dist or post_dist or ensured_targets:
         _make_wrapper(sdist, pre_dist, post_dist)
         _make_wrapper(bdist_wheel, pre_dist, post_dist)
 
@@ -236,6 +241,15 @@ def get_version(fpath, name='__version__'):
     return version_ns[name]
 
 
+def get_version_info(version_str):
+    """Get a version info tuple given a version string"""
+    parsed = parse_version(version_str)
+    version_info = [parsed.major, parsed.minor, parsed.micro]
+    if parsed.base_version != parsed.public:
+        version_info.append(parsed.public[len(parsed.base_version):])
+    return tuple(version_info)
+
+
 def run(cmd, **kwargs):
     """Echo a command before running it."""
     log.info('> ' + list2cmdline(cmd))
